@@ -75,6 +75,13 @@ chr.omit <- function(x, omit = "", na.omit = FALSE, check = TRUE) {
 
   }
 
+  #---------------------
+  # Convert 'x' into a vector
+  x <- unlist(x, use.names = FALSE)
+
+  #-----------------------------------------
+  # Input Check
+
   #.............
   # Check input 'check'
   if (isTRUE(!is.logical(check))) {
@@ -83,18 +90,8 @@ chr.omit <- function(x, omit = "", na.omit = FALSE, check = TRUE) {
 
   }
 
-  #-----------------------------------------
-
   if (isTRUE(check)) {
 
-    #.............
-    # Check input 'x': Vector?
-    if (isTRUE(!is.null(dim(x)))) {
-
-      stop("Please specify a vector for the argument 'x'.", call. = FALSE)
-
-    }
-
     #.............
     # Check input 'omit': Values in 'x'?
     na.x <- vapply(omit, function(y) !y %in% x, FUN.VALUE = logical(1))
