@@ -1,22 +1,28 @@
 #' Auxiliary variables analysis
 #'
-#' This function computes (1) Pearson product-moment correlation matrix to identify variables related
-#' to the incomplete variable and (2) Cohen's d comparing cases with and without missing values to
-#' identify variables related to the probability of missingness.
+#' This function computes (1) Pearson product-moment correlation matrix to identify
+#' variables related to the incomplete variable and (2) Cohen's d comparing cases
+#' with and without missing values to identify variables related to the probability
+#' of missingness.
 #'
-#' Note that non-numeric variables (i.e., factors, character vectors, and logical vectors) are excluded from to the analysis.
+#' Note that non-numeric variables (i.e., factors, character vectors, and logical
+#' vectors) are excluded from to the analysis.
 #'
 #' @param x           a matrix or data frame with numeric vectors.
-#' @param tri         a character string indicating which triangular of the correlation matrix to show on the console,
-#'                    i.e., \code{both} for upper and lower triangular, \code{lower} (default) for the
-#'                    lower triangular, and \code{upper} for the upper triangular.
-#' @param weighted    logical: if \code{TRUE} (default), the weighted pooled standard deviation is used.
-#' @param correct     logical: if \code{TRUE}, correction factor for Cohen's d to remove positive bias
-#'                    in small samples is used.
-#' @param digits      integer value indicating the number of decimal places digits to be used for displaying
-#'                    correlation coefficients and Cohen's d estimates.
+#' @param tri         a character string indicating which triangular of the correlation
+#'                    matrix to show on the console, i.e., \code{both} for upper and
+#'                    lower triangular, \code{lower} (default) for the lower triangular,
+#'                    and \code{upper} for the upper triangular.
+#' @param weighted    logical: if \code{TRUE} (default), the weighted pooled standard
+#'                    deviation is used.
+#' @param correct     logical: if \code{TRUE}, correction factor for Cohen's d to
+#'                    remove positive bias in small samples is used.
+#' @param digits      integer value indicating the number of decimal places digits
+#'                    to be used for displaying correlation coefficients and Cohen's d
+#'                    estimates.
 #' @param as.na       a numeric vector indicating user-defined missing values,
-#'                    i.e. these values are converted to \code{NA} before conducting the analysis.
+#'                    i.e. these values are converted to \code{NA} before conducting
+#'                    the analysis.
 #' @param check       logical: if \code{TRUE}, argument specification is checked.
 #' @param output      logical: if \code{TRUE}, output is shown on the console.
 #'
@@ -24,22 +30,25 @@
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
 #' @seealso
-#' \code{\link{as.na}}, \code{\link{na.as}}, \code{\link{na.coverage}}, \code{\link{na.descript}},
-#' \code{\link{na.indicator}}, \code{\link{na.pattern}}, \code{\link{na.prop}}.
+#' \code{\link{as.na}}, \code{\link{na.as}}, \code{\link{na.coverage}},
+#' \code{\link{na.descript}}, \code{\link{na.indicator}}, \code{\link{na.pattern}},
+#' \code{\link{na.prop}}, \code{\link{na.test}}
 #'
 #' @references
 #' Enders, C. K. (2010). \emph{Applied missing data analysis}. Guilford Press.
 #'
 #' Graham, J. W. (2009). Missing data analysis: Making it work in the real world.
-#' \emph{Annual Review of Psychology, 60}, 549-576. https://doi.org/10.1146/annurev.psych.58.110405.085530
+#' \emph{Annual Review of Psychology, 60}, 549-576.
+#' https://doi.org/10.1146/annurev.psych.58.110405.085530
 #'
-#' van Buuren, S. (2018). \emph{Flexible imputation of missing data} (2nd ed.). Chapman & Hall.
+#' van Buuren, S. (2018). \emph{Flexible imputation of missing data} (2nd ed.).
+#' Chapman & Hall.
 #'
 #' @return
-#' Returns an object of class \code{misty.object}, which is a list with following entries:
-#' function call (\code{call}), type of analysis \code{type}, matrix or data frame specified in
-#' \code{x} (\code{data}), specification of function arguments (\code{args}), and
-#' list with results (\code{result}).
+#' Returns an object of class \code{misty.object}, which is a list with following
+#' entries: function call (\code{call}), type of analysis \code{type}, matrix or
+#' data frame specified in \code{x} (\code{data}), specification of function arguments
+#' (\code{args}), and list with results (\code{result}).
 #'
 #' @export
 #'
@@ -51,8 +60,9 @@
 #'
 #' # Auxiliary variables
 #' na.auxiliary(dat)
-na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE, correct = FALSE,
-                         digits = 2, as.na = NULL, check = TRUE, output = TRUE) {
+na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
+                         correct = FALSE, digits = 2, as.na = NULL, check = TRUE,
+                         output = TRUE) {
 
 
   ####################################################################################
@@ -99,8 +109,8 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
     # Variance by group
     var.group <- tapply(x.dat, group.dat, var, na.rm = TRUE)
 
-   # Weighted pooled standard deviation
-   if (isTRUE(weighted)) {
+    # Weighted pooled standard deviation
+    if (isTRUE(weighted)) {
 
     sd.group <- sqrt(((n.group[1L] - 1L)*var.group[1] + (n.group[2L] - 1L)*var.group[2L]) / (sum(n.group) - 2L))
 
